# ----------------------------------------------------------------------
# Curses::UI::Language::english
# Maintainer: marcus@thiesenweb.de
# ----------------------------------------------------------------------

package Curses::UI::Language::english; 
1;
__DATA__

# ----------------------------------------------------------------------
# For Curses::UI
# ----------------------------------------------------------------------

[screen_too_small]
Your screen is currently too small for this application.
Resize the screen and restart the application.
Press <CTRL+C> to exit...

# ----------------------------------------------------------------------
# For Curses::UI::Calendar
# ----------------------------------------------------------------------

[months]
January February March April May June July 
August September October November December

[days_short] Su Mo Tu We Th Fr Sa

# ----------------------------------------------------------------------
# For Curses::UI::Buttonbox
# ----------------------------------------------------------------------

[button_ok]      o:OK
[button_cancel]  c:Cancel
[button_yes]     y:Yes
[button_no]      n:No

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::Error
# ----------------------------------------------------------------------

[error_title]    Error message

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::FileBrowser
# ----------------------------------------------------------------------

# The filebrowser title
[file_title]     Select a file
[file_savetitle] Select a file to save to
[file_loadtitle] Select a file to load from

# The dirbrowser title
[dir_title]     Select a directory

# The labels for the dialog screen.
[file_path]      Path :
[file_file]      File :
[file_mask]      Mask :

# The size of the longest label
[file_labelsize] 6

# On directory up
[file_dirup] Parent directory

# For asking the user if a file may be overwritten
[file_overwrite_title] Confirm
[file_overwrite_question_pre] 
Do you really want to overwrite the file "
[file_overwrite_question_post] 
"?

# Errors
[file_err_opendir_pre] Can't open directory "
[file_err_opendir_post] "
[file_err_nofileselected] You have not selected a file!


